@@ -1,10 +1,3 @@
-#' @importFrom insight get_data find_interactions
-#' @importFrom stats formula sd quantile
-#' @importFrom purrr map map_lgl map_chr
-#' @importFrom sjmisc trim is_empty str_contains is_float
-#' @importFrom dplyr select n_distinct
-#' @importFrom ggeffects ggpredict
-#' @importFrom graphics plot
 plot_type_int <- function(model,
                           mdrt.values,
                           ci.lvl,
@@ -35,13 +28,13 @@ plot_type_int <- function(model,
   # get interaction terms and model frame
 
   ia.terms <- purrr::map(int.terms, ~ sjmisc::trim(unlist(strsplit(.x, "[\\*:]"))))
-  mf <- insight::get_data(model)
+  mf <- insight::get_data(model, verbose = FALSE)
 
   pl <- list()
 
   # intertate interaction terms
 
-  for (i in 1:length(ia.terms)) {
+  for (i in seq_along(ia.terms)) {
 
     ia <- ia.terms[[i]]
     find.fac <- purrr::map_lgl(ia, ~ is_categorical(mf[[.x]]))
@@ -109,7 +102,7 @@ plot_type_int <- function(model,
     dat <- ggeffects::ggpredict(
       model = model,
       terms = ia,
-      ci.lvl = ci.lvl,
+      ci_lvl = ci.lvl,
       type = pred.type,
       full.data = FALSE,
       ...
@@ -139,20 +132,20 @@ plot_type_int <- function(model,
 
     p <- graphics::plot(
       dat,
-      ci = !is.na(ci.lvl),
+      show_ci = !is.na(ci.lvl),
       facets = facets,
-      rawdata = show.data,
+      show_data = show.data,
       colors = geom.colors,
       jitter = jitter,
-      use.theme = FALSE,
+      use_theme = FALSE,
       case = case,
-      show.legend = show.legend,
-      dot.alpha = dot.alpha,
+      show_legend = show.legend,
+      dot_alpha = dot.alpha,
       alpha = alpha,
       dodge = dodge,
-      log.y = log.y,
-      dot.size = dot.size,
-      line.size = line.size
+      log_y = log.y,
+      dot_size = dot.size,
+      line_size = line.size
     )
 
     # set axis and plot titles
